use actix_web::{web, HttpResponse, Responder};
use askama_actix::TemplateToResponse;
use chrono::NaiveTime;
use sqlx::PgPool;

use crate::{
    endpoints::{availability::AvailabillityEditTemplate, IdPath},
    models::{Availabillity, User},
};

#[actix_web::get("/availabillity/edit/{id}")]
pub async fn get(
    user: web::ReqData<User>,
    pool: web::Data<PgPool>,
    path: web::Path<IdPath>,
) -> impl Responder {
    if let Ok(availabillity) = Availabillity::read_by_id(pool.get_ref(), path.id).await {
        if availabillity.user_id == user.id {
            let start_time = availabillity
                .start_time
                .unwrap_or(NaiveTime::from_hms_opt(0, 0, 0).unwrap())
                .format("%R")
                .to_string();

            let end_time = availabillity
                .end_time
                .unwrap_or(NaiveTime::from_hms_opt(23, 59, 0).unwrap())
                .format("%R")
                .to_string();

            let has_time = availabillity.start_time.is_some() && availabillity.end_time.is_some();

            let comment = availabillity.comment.unwrap_or(String::new());

            let template = AvailabillityEditTemplate {
                user: user.into_inner(),
                date: availabillity.date,
                id: path.id,
                start_time,
                end_time,
                has_time,
                comment,
            };

            return template.to_response();
        }
    }

    HttpResponse::BadRequest().body("Availabillity with this id doesn't exist.")
}
